fn encode_structured_json<S: Encoder>(
query_ctx: &QueryContextRef,
column: &ArrayRef,
i: usize,
encoder: &mut S,
pg_field: &FieldInfo,
) -> PgWireResult<()>Expand description
Encodes one row of a structured column (Struct, or List of Struct) as
a PostgreSQL json value.
Returns an error for arrow field types greptimedb cannot represent
(e.g. Decimal256) instead of panicking, so the client receives a proper
error response.